@@ -1,6 +1,6 @@
 /*============================================================================
 
-  WCSLIB 5.20 - an implementation of the FITS WCS standard.
+  WCSLIB 6.2 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2018, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -22,10 +22,10 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: fitshdr.h,v 5.20 2018/10/05 05:32:41 mcalabre Exp $
+  $Id: fitshdr.h,v 6.2 2018/10/20 10:03:13 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 5.20 - C routines that implement the FITS World Coordinate System
+* WCSLIB 6.2 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -391,6 +391,13 @@ extern "C" {
 
 extern const char *fitshdr_errmsg[];
 
+enum fitshdr_errmsg_enum {
+  FITSHDRERR_SUCCESS      = 0,	/* Success.                                 */
+  FITSHDRERR_NULL_POINTER = 1,	/* Null fitskey pointer passed.             */
+  FITSHDRERR_MEMORY       = 2,	/* Memory allocation failed.                */
+  FITSHDRERR_FLEX_PARSER  = 3	/* Fatal error returned by Flex parser.     */
+};
+
 #ifdef WCSLIB_INT64
   typedef WCSLIB_INT64 int64;
 #else
